Skip to contents

Returns a named list of blocked nodes mapped to their block reasons. Call dagri_recompute_state() before using this function to ensure node states are current.

Usage

dagri_blocked(graph)

Arguments

graph

A dagri_graph.