Returns IDs of nodes whose state is "ready". Call dagri_recompute_state()
before using this function to ensure node states are current.
Returns IDs of nodes whose state is "ready". Call dagri_recompute_state()
before using this function to ensure node states are current.