Returns a named list of blocked nodes mapped to their block reasons. Call
dagri_recompute_state() before using this function to ensure node
states are current.
Returns a named list of blocked nodes mapped to their block reasons. Call
dagri_recompute_state() before using this function to ensure node
states are current.